@@ -1,10 +1,10 @@
 package Test::Compile;
 
-use 5.6.2;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v1.2.1");
+use version; our $VERSION = qv("v2.0_0");
+use parent 'Exporter';
 use UNIVERSAL::require;
 use Test::Compile::Internal;
 
@@ -22,8 +22,8 @@ Test::Compile - Check whether Perl files compile correctly.
     $test->all_files_ok();
     $test->done_testing();
 
-    # The procedural way
-    use Test::Compile;
+    # The procedural way (deprecated)
+    use Test::Compile qw( all_pm_files_ok );
     all_pm_files_ok();
 
 =head1 DESCRIPTION
@@ -48,21 +48,18 @@ in a module distribution:
 
 =cut
 
-sub import {
-    my $self   = shift;
-    my $caller = caller;
-    for my $func (
-        qw(
-        pm_file_ok pl_file_ok all_pm_files all_pl_files all_pm_files_ok
-        all_pl_files_ok
-        )
-      ) {
-        no strict 'refs';
-        *{ $caller . "::" . $func } = \&$func;
-    }
-    $Test->exported_to($caller);
-    $Test->plan(@_);
-}
+our @EXPORT_OK = qw(
+    pm_file_ok
+    pl_file_ok
+
+    all_files_ok
+    all_pm_files_ok
+    all_pl_files_ok
+
+    all_pm_files
+    all_pl_files
+);
+our %EXPORT_TAGS = ('all' => \@EXPORT_OK);
 
 =head1 METHODS
 
@@ -85,7 +82,7 @@ sub new {
 Checks all the perl files it can find for compilation errors.
 
 If C<@dirs> is defined then it is taken as an array of directories to
-be searched for perl files, otherwise it searches some default locatioons
+be searched for perl files, otherwise it searches some default locations
 - see L</all_pm_files()> and L</all_pl_files()>.
 
 =item C<all_pm_files(@dirs)>
@@ -140,7 +137,7 @@ access to some of its methods.
 
 Declares that you are done testing, no more tests will be run after this point.
 
-=item C<ok($test,$name)>
+=item C<ok($test, $name)>
 
 Your basic test. Pass if C<$test> is true, fail if C<$test> is false. Just
 like C<Test::Simple>'s C<ok()>.
@@ -149,11 +146,6 @@ like C<Test::Simple>'s C<ok()>.
 
 Defines how many tests you plan to run.
 
-=item C<exported_to($caller)>
-
-Tells C<Test::Builder> what package you exported your functions to.  I am
-not sure why you would want to do that, or whether it would do you any good.
-
 =item C<diag(@msgs)>
 
 Prints out the given C<@msgs>. Like print, arguments are simply appended
@@ -176,6 +168,15 @@ Skips all the tests, using the given C<$reason>. Exits immediately with 0.
 
 =head1 FUNCTIONS
 
+The use of the following functions is deprecated and strongly discouraged.
+
+They are automatically exported to your namespace,  which is
+no longer considered best practise.  At some stage in the future, this will
+stop and you'll have to import them explicitly.
+
+Even then, you really should use the object oriented methods as they provide
+a more consistent interface.
+
 =over 4
 
 =item C<all_pm_files_ok(@files)>
@@ -202,7 +203,9 @@ in a module distribution:
     eval "use Test::Compile";
     Test::More->builder->BAIL_OUT(
         "Test::Compile required for testing compilation") if $@;
-    all_pm_files_ok();
+    my $test = Test::Compile->new();
+    $test->all_pm_files_ok();
+    $test->done_testing();
 
 =cut
 
@@ -240,7 +243,9 @@ in a module distribution:
     eval "use Test::Compile";
     plan skip_all => "Test::Compile required for testing compilation"
       if $@;
-    all_pl_files_ok();
+    my $test = Test::Compile->new();
+    $test->all_pl_files_ok();
+    $test->done_testing();
 
 =cut
 
@@ -255,7 +260,7 @@ sub all_pl_files_ok {
     $ok;
 }
 
-=item C<pm_file_ok($filename,$testname)>
+=item C<pm_file_ok($filename, $testname)>
 
 C<pm_file_ok()> will okay the test if $filename compiles as a perl module.
 
@@ -265,7 +270,7 @@ $filename>.
 
 =cut
 sub pm_file_ok {
-    my ($file,$name) = @_;
+    my ($file, $name) = @_;
 
     $name ||= "Compile test for $file";
 
@@ -276,7 +281,7 @@ sub pm_file_ok {
     return $ok;
 }
 
-=item C<pl_file_ok($filename,$testname)>
+=item C<pl_file_ok($filename, $testname)>
 
 C<pl_file_ok()> will okay the test if $filename compiles as a perl script. You
 need to give the path to the script relative to this distribution's base
@@ -289,7 +294,7 @@ $filename>.
 =cut
 
 sub pl_file_ok {
-    my ($file,$name) = @_;
+    my ($file, $name) = @_;
 
     $name ||= "Compile test for $file";
 
@@ -343,13 +348,26 @@ Skips any files in C<CVS> or C<.svn> directories.
 The order of the files returned is machine-dependent. If you want them
 sorted, you'll have to sort them yourself.
 
-=back
 =cut
 
 sub all_pl_files {
     return $Test->all_pl_files(@_);
 }
 
+=item C<all_files_ok(@dirs)>
+
+Checks all the perl files it can find for compilation errors.
+
+If C<@dirs> is defined then it is taken as an array of directories to
+be searched for perl files, otherwise it searches some default locations
+- see L</all_pm_files()> and L</all_pl_files()>.
+
+=back
+=cut
+sub all_files_ok {
+    return $Test->all_files_ok(@_);
+}
+
 sub _verbose {
     return $Test->verbose(@_);
 }
@@ -364,7 +382,7 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2014 by the authors.
+Copyright 2007-2015 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -374,7 +392,7 @@ it under the same terms as Perl itself.
 L<Test::Compile::Internal> provides the object oriented interface to (and the
 inner workings for) the Test::Compile functionality.
 
-L<Test::Strict> proveds functions to ensure your perl files comnpile, with
+L<Test::Strict> provides functions to ensure your perl files compile, with
 added bonus that it will check you have used strict in all your files.
 L<Test::LoadAllModules> just handles modules, not script files, but has more
 fine-grained control.
