@@ -1,10 +1,9 @@
 package Test::Compile::Internal;
 
-use 5.6.2;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v1.2.1");
+use version; our $VERSION = qv("v2.0_0");
 use File::Spec;
 use UNIVERSAL::require;
 use Test::Builder;
@@ -38,7 +37,7 @@ A basic constructor, nothing special.
 =cut
 
 sub new {
-    my ($class,%self) = @_;
+    my ($class, %self) = @_;
     my $self = \%self;
 
     $self->{test} = Test::Builder->new();
@@ -51,38 +50,38 @@ sub new {
 
 Checks all the perl files it can find for compilation errors.
 
-If C<@dirs> is defined then it is taken as an array of directories to 
-be searched for perl files, otherwise it searches some default locatioons
-- see L</all_pm_files()> and L</all_pl_files()>. 
+If C<@dirs> is defined then it is taken as an array of directories to
+be searched for perl files, otherwise it searches some default locations
+- see L</all_pm_files()> and L</all_pl_files()>.
 
 =cut
 sub all_files_ok {
-    my ($self,@dirs) = @_;
+    my ($self, @dirs) = @_;
 
     my $test = $self->{test};
 
     for my $file ( $self->all_pl_files(@dirs) ) {
         my $ok = $self->pl_file_compiles($file);
-        $test->ok($ok,"$file compiles");
+        $test->ok($ok, "$file compiles");
     }
 
     for my $file ( $self->all_pm_files(@dirs) ) {
         my $ok = $self->pm_file_compiles($file);
-        $test->ok($ok,"$file compiles");
+        $test->ok($ok, "$file compiles");
     }
 }
 
 
 =item C<verbose($verbose)>
 
-An accessor to get/set the verbose flag.  If C<verbose> is set, you can get some 
+An accessor to get/set the verbose flag.  If C<verbose> is set, you can get some
 extra diagnostics when compilation fails.
 
 Verbose is set on by default.
 =cut
 
 sub verbose {
-    my ($self,$verbose) = @_;
+    my ($self, $verbose) = @_;
 
     if ( defined($verbose) ) {
         $self->{verbose} = $verbose;
@@ -104,7 +103,7 @@ sorted, you'll have to sort them yourself.
 =cut
 
 sub all_pm_files {
-    my ($self,@dirs) = @_;
+    my ($self, @dirs) = @_;
 
     @dirs = @dirs ? @dirs : _pm_starting_points();
 
@@ -133,7 +132,7 @@ sorted, you'll have to sort them yourself.
 =cut
 
 sub all_pl_files {
-    my ($self,@dirs) = @_;
+    my ($self, @dirs) = @_;
 
     @dirs = @dirs ? @dirs : _pl_starting_points();
 
@@ -163,14 +162,18 @@ Returns true if C<$file> compiles as a perl script.
 =cut
 
 sub pl_file_compiles {
-    my ($self,$file) = @_;
-    return $self->_run_closure(
+    my ($self, $file) = @_;
+    return $self->_run_subprocess(
         sub{
             if ( -f $file ) {
                 my @inc = ('blib/lib', @INC);
                 my $taint = $self->_is_in_taint_mode($file);
                 system($^X, (map { "-I$_" } @inc), "-c$taint", $file);
-                return ($? ? 0 : 1);
+                return ($? == 0);
+            }
+            else {
+                $self->{test}->diag("$file could not be found") if $self->verbose();
+                return 0;
             }
         }
     );
@@ -185,16 +188,16 @@ Returns true if C<$file> compiles as a perl module.
 =cut
 
 sub pm_file_compiles {
-    my ($self,$file,%args) = @_;
+    my ($self, $file, %args) = @_;
 
-    return $self->_run_closure(
+    return $self->_run_subprocess(
         sub{
             if ( -f $file ) {
                 my $module = $file;
                 $module =~ s!^(blib[/\\])?lib[/\\]!!;
                 $module =~ s![/\\]!::!g;
                 $module =~ s/\.pm$//;
-    
+
                 return 1 if $module->require;
 
                 $self->{test}->diag("Compilation of $module failed: $@")
@@ -222,18 +225,18 @@ Declares that you are done testing, no more tests will be run after this point.
 
 =cut
 sub done_testing {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->done_testing(@args);
 }
 
-=item C<ok($test,$name)>
+=item C<ok($test, $name)>
 
 Your basic test. Pass if C<$test> is true, fail if C<$test> is false. Just
 like C<Test::Simple>'s C<ok()>.
 
 =cut
 sub ok {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->ok(@args);
 }
 
@@ -243,22 +246,10 @@ Defines how many tests you plan to run.
 
 =cut
 sub plan {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->plan(@args);
 }
 
-=item C<exported_to($caller)>
-
-Tells C<Test::Builder> what package you exported your functions to.  I am
-not sure why you would want to do that, or whether it would do you any good.
-
-=cut
-
-sub exported_to {
-    my ($self,@args) = @_;
-    $self->{test}->exported_to(@args);
-}
-
 =item C<diag(@msgs)>
 
 Prints out the given C<@msgs>. Like print, arguments are simply appended
@@ -272,7 +263,7 @@ We encourage using this rather than calling print directly.
 =cut
 
 sub diag {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->diag(@args);
 }
 
@@ -283,7 +274,7 @@ Skips the current test, reporting the C<$reason>.
 =cut
 
 sub skip {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->skip(@args);
 }
 
@@ -295,12 +286,12 @@ Skips all the tests, using the given C<$reason>. Exits immediately with 0.
 =cut
 
 sub skip_all {
-    my ($self,@args) = @_;
+    my ($self, @args) = @_;
     $self->{test}->skip_all(@args);
 }
 
-sub _run_closure {
-    my ($self,$closure) = @_;
+sub _run_subprocess {
+    my ($self, $closure) = @_;
 
     my $pid = fork();
     if ( ! defined($pid) ) {
@@ -320,7 +311,7 @@ sub _run_closure {
 }
 
 sub _find_files {
-    my ($self,@queue) = @_;
+    my ($self, @queue) = @_;
 
     for my $file (@queue) {
         if (defined($file) && -d $file) {
@@ -329,7 +320,7 @@ sub _find_files {
             my @newfiles = readdir DH;
             closedir DH;
             @newfiles = File::Spec->no_upwards(@newfiles);
-            @newfiles = grep { $_ ne "CVS" && $_ ne ".svn" } @newfiles;
+            @newfiles = grep { $_ ne "CVS" && $_ ne ".svn" && $_ ne ".git" } @newfiles;
             for my $newfile (@newfiles) {
                 my $filename = File::Spec->catfile($file, $newfile);
                 if (-f $filename) {
@@ -354,7 +345,7 @@ sub _pl_starting_points {
 }
 
 sub _read_shebang {
-    my ($self,$file) = @_;
+    my ($self, $file) = @_;
 
     open(my $f, "<", $file) or die "could not open $file";
     my $line = <$f>;
@@ -364,7 +355,7 @@ sub _read_shebang {
 }
 
 sub _is_in_taint_mode {
-    my ($self,$file) = @_;
+    my ($self, $file) = @_;
 
     my $shebang = $self->_read_shebang($file);
     my $taint = "";
@@ -384,14 +375,14 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2014 by the authors.
+Copyright 2007-2015 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Test::Strict> proveds functions to ensure your perl files comnpile, with
+L<Test::Strict> provides functions to ensure your perl files compile, with
 the added bonus that it will check you have used strict in all your files.
 
 =cut
